//
//  @file M5StickC_RCB4_MotionPlay.ino
//  @brief M5StickC RCB-4 MotionPlay sample
//  @author Kondo Kagaku Co.,Ltd.
//  @date 2020/4/23
//
//  M5StickCからRCB-4に登録されたモーションを再生
//  RCB-4変換基板を中継する
//

#include <M5StickC.h>
#include <Rcb4HardSerialClass.h>


const long BAUDRATE = 115200; //通信速度
const int TIMEOUT = 1000;     //タイムアウトまでの時間指定

const int TX_PIN = 26;        //M5StickCのTXピン指定
const int RX_PIN = 36;        //M5StickCのRXピン指定

Rcb4HardSerialClass rcb4(&Serial1); //RCB4HardSerialClassの定義

//RCB-4との通信を開始するための関数
//RCB-4ライブラリの標準関数ではM5StickCのシリアル通信設定に対応していないため
//別途以下の関数を使用する
void rcb4SerialOpen()
{
  //シリアル通信を開始します。
  //(通信速度、パリティ、受信端子指定、送信端子指定、論理反転指定、タイムアウト)
  Serial1.begin(BAUDRATE, SERIAL_8E1, RX_PIN, TX_PIN, false, TIMEOUT);

  //接続されているか確認します。
  //データが返ってくるまで待ちます。
  while(rcb4.checkAcknowledge() == false)
  {
    M5.Lcd.setCursor(0, 0);
    M5.Lcd.print("ChackFalse");
  }

  delay(100);

  //コンフィグデータを取得し、クラス内部に保存しておきます
  rcb4.getConfig();
}


void setup()
{

  M5.begin();

  //LCD設定
  M5.Lcd.setRotation(3);    //LCDの表示を横に設定
  M5.Lcd.fillScreen(BLACK); //LCDの背景を黒に設定
  M5.Lcd.setTextSize(2);    //フォントサイズを2に設定
  M5.Lcd.setCursor(0, 0);   //カーソルを左上に指定

  rcb4.configData.word = 0xffff;      //ConfigDataは間違えないように0xFFFFで初期化
  
  rcb4SerialOpen();                   //RCB-4との通信を開始

  //RCB-4との通信が確立したら以下の処理を続行
  M5.Lcd.setCursor(0, 0);
  M5.Lcd.print("COM Open OK!");       //文字を表示
  delay(1000);

  //表示を消す
  M5.Lcd.setCursor(0, 0);
  M5.Lcd.print("             ");
}

void loop()
{
  while (rcb4.configData.word == 0xffff);   //configDataが読み取れてない場合は無限ループ

  M5.Lcd.setCursor(0, 0);
  M5.Lcd.println("Motion No.7");

  if(rcb4.motionPlay(7) == true)  //モーション7を再生
  {
    M5.Lcd.print("Left Step");
    delay(8000);                  //モーションが終了するまで待つ
  }
  else                            //通信失敗時
  {
    M5.Lcd.print("Failure");
    delay(1000);
  }

  //表示を消す
  M5.Lcd.setCursor(0, 0);
  M5.Lcd.println("            ");
  M5.Lcd.print("           ");

  M5.Lcd.setCursor(0, 0);
  M5.Lcd.println("Motion No.8");

  if(rcb4.motionPlay(8) == true)  //モーション8を再生
  {
    M5.Lcd.print("Right Step");
    delay(8000);                  //モーションが終了するまで待つ
  }
  else                            //通信失敗時
  {
    M5.Lcd.print("Failure");
    delay(1000);
  }

  //表示を消す
  M5.Lcd.setCursor(0, 0);
  M5.Lcd.println("            ");
  M5.Lcd.print("           ");
}
